/*
  MOD-MAG example.
  
  Reads the raw data from the
  module's registers.
  
  Values may need calibrating. Please
  refer to the MAG3110 Reference manual
  for detailed information.
  
  If you have any questions, email
  support@olimex.com
  
  https://www.olimex.com
  OLIMEX, 2013
*/

#include "MODMAG.h"

// Declare the MOD-MAG device
// The MOD-MAG has a single MAG3110 chip
// The board connects to the MOD via I2C
// Refer to MODMAG.h or the MAG3110 reference
// manual for detailed information on the protocol used.
// The modmag class has been configured to work with the
// default I2C pins SDA and SCL (as defined for each board
// pins_arduino.h)
MODMAG modmag;
     
void print_data();

void setup(){
  
  Serial.begin(9600);
}

void loop(){
  
  print_data();      
  Serial.println("");
  Serial.println("");
  
  delay(500);
  
}

void print_data(){
  unsigned char aflag;
  Serial.print("CHIP ID: ");
  uint8_t chip_id = modmag.ReadSingleIadr(0x07, aflag);
  Serial.println(chip_id, BIN);
  
  //Update values to current data
  //The MODMAG.h library uses the "Trigger Measurement" mode
  //Refer to the MAG3110 manual for detailed information
  //pages 12 and 17
  modmag.updateData();
  
  Serial.println("Raw Data:");
  Serial.print("X: "); Serial.println(modmag.getX(), DEC); 
  Serial.print("Y: "); Serial.println(modmag.getY(), DEC);
  Serial.print("Z: "); Serial.println(modmag.getZ(), DEC); 
  Serial.print("Temperature: "); Serial.println(modmag.getTemperature(), DEC);
}
